@@ -11,7 +11,7 @@ class RiskListViewSet(NetBoxModelViewSet):
 
 
 class RiskRelationListViewSet(NetBoxModelViewSet):
-    queryset = models.RiskRelation.objects.prefetch_related('tags')
+    queryset = models.RiskRelation.objects.prefetch_related('tagsx')
     serializer_class = RiskRelationSerializer
 
 
